@@ -114,7 +114,7 @@ Kolf::LandscapeOverlay::LandscapeOverlay(Kolf::LandscapeItem* item)
 		Kolf::OverlayHandle* handle = new Kolf::OverlayHandle(Kolf::OverlayHandle::CircleShape, this);
 		m_handles << handle;
 		addHandle(handle);
-		connect(handle, SIGNAL(moveRequest(QPointF)), this, SLOT(moveHandle(QPointF)));
+		connect(handle, &Kolf::OverlayHandle::moveRequest, this, &Kolf::LandscapeOverlay::moveHandle);
 	}
 }
 
@@ -158,16 +158,16 @@ Kolf::LandscapeConfig::LandscapeConfig(Kolf::LandscapeItem* item, QWidget* paren
 	vlayout->addStretch();
 
 	checkBox->setChecked(true);
-	connect(checkBox, SIGNAL(toggled(bool)), label1, SLOT(setEnabled(bool)));
-	connect(checkBox, SIGNAL(toggled(bool)), label2, SLOT(setEnabled(bool)));
-	connect(checkBox, SIGNAL(toggled(bool)), slider, SLOT(setEnabled(bool)));
-	connect(checkBox, SIGNAL(toggled(bool)), item, SLOT(setBlinkEnabled(bool)));
+	connect(checkBox, &QCheckBox::toggled, label1, &QLabel::setEnabled);
+	connect(checkBox, &QCheckBox::toggled, label2, &QLabel::setEnabled);
+	connect(checkBox, &QCheckBox::toggled, slider, &QSlider::setEnabled);
+	connect(checkBox, &QCheckBox::toggled, item, &Kolf::LandscapeItem::setBlinkEnabled);
 	checkBox->setChecked(item->isBlinkEnabled());
 	slider->setRange(1, 100);
 	slider->setPageStep(5);
 	slider->setValue(100 - item->blinkInterval());
-	connect(slider, SIGNAL(valueChanged(int)), SLOT(setBlinkInterval(int)));
-	connect(this, SIGNAL(blinkIntervalChanged(int)), item, SLOT(setBlinkInterval(int)));
+	connect(slider, &QSlider::valueChanged, this, &Kolf::LandscapeConfig::setBlinkInterval);
+	connect(this, &Kolf::LandscapeConfig::blinkIntervalChanged, item, &Kolf::LandscapeItem::setBlinkInterval);
 }
 
 void Kolf::LandscapeConfig::setBlinkInterval(int sliderValue)
@@ -179,7 +179,7 @@ void Kolf::LandscapeConfig::setBlinkInterval(int sliderValue)
 //BEGIN Kolf::Puddle
 
 Kolf::Puddle::Puddle(QGraphicsItem* parent, b2World* world)
-	: Kolf::LandscapeItem(QLatin1String("puddle"), parent, world)
+	: Kolf::LandscapeItem(QStringLiteral("puddle"), parent, world)
 {
 	setData(0, Rtti_DontPlaceOn);
 	setSize(QSizeF(45, 30));
@@ -193,7 +193,7 @@ bool Kolf::Puddle::collision(Ball* ball)
 	if (!contains(ball->pos() - pos()))
 		return true;
 	//ball is visible and has reached the puddle
-	playSound("puddle");
+	game->playSound(Sound::Puddle);
 	ball->setAddStroke(ball->addStroke() + 1);
 	ball->setPlaceOnGround(true);
 	ball->setVisible(false);
@@ -208,7 +208,7 @@ bool Kolf::Puddle::collision(Ball* ball)
 //BEGIN Kolf::Sand
 
 Kolf::Sand::Sand(QGraphicsItem* parent, b2World* world)
-	: Kolf::LandscapeItem(QLatin1String("sand"), parent, world)
+	: Kolf::LandscapeItem(QStringLiteral("sand"), parent, world)
 {
 	setSize(QSizeF(45, 40));
 	setZBehavior(CanvasItem::FixedZValue, 2);
@@ -230,26 +230,26 @@ struct SlopeData
 	QStringList spriteKeys, reversedSpriteKeys;
 	SlopeData()
 	{
-		gradientKeys << QLatin1String("Vertical")
-		             << QLatin1String("Horizontal")
-		             << QLatin1String("Diagonal")
-		             << QLatin1String("Opposite Diagonal")
-		             << QLatin1String("Elliptic");
+		gradientKeys << QStringLiteral("Vertical")
+		             << QStringLiteral("Horizontal")
+		             << QStringLiteral("Diagonal")
+		             << QStringLiteral("Opposite Diagonal")
+		             << QStringLiteral("Elliptic");
 		translatedGradientKeys << i18n("Vertical")
 		             << i18n("Horizontal")
 		             << i18n("Diagonal")
 		             << i18n("Opposite Diagonal")
 		             << i18n("Elliptic");
-		spriteKeys   << QLatin1String("slope_n")
-			         << QLatin1String("slope_w")
-			         << QLatin1String("slope_nw")
-			         << QLatin1String("slope_ne")
-			         << QLatin1String("slope_bump");
-		reversedSpriteKeys << QLatin1String("slope_s")
-			         << QLatin1String("slope_e")
-			         << QLatin1String("slope_se")
-			         << QLatin1String("slope_sw")
-			         << QLatin1String("slope_dip");
+		spriteKeys   << QStringLiteral("slope_n")
+			         << QStringLiteral("slope_w")
+			         << QStringLiteral("slope_nw")
+			         << QStringLiteral("slope_ne")
+			         << QStringLiteral("slope_bump");
+		reversedSpriteKeys << QStringLiteral("slope_s")
+			         << QStringLiteral("slope_e")
+			         << QStringLiteral("slope_se")
+			         << QStringLiteral("slope_sw")
+			         << QStringLiteral("slope_dip");
 	}
 };
 Q_GLOBAL_STATIC(SlopeData, g_slopeData)
@@ -564,18 +564,18 @@ Kolf::SlopeConfig::SlopeConfig(Kolf::Slope* slope, QWidget* parent)
 	KComboBox* typeBox = new KComboBox(this);
 	typeBox->addItems(g_slopeData->translatedGradientKeys);
 	typeBox->setCurrentIndex(slope->slopeType());
-	connect(typeBox, SIGNAL(currentIndexChanged(int)), slope, SLOT(setSlopeType(int)));
+	connect(typeBox, QOverload<int>::of(&KComboBox::currentIndexChanged), slope, &Kolf::Slope::setSlopeType);
 	layout->addWidget(typeBox, 0, 0, 1, 2);
 
 	QCheckBox* reversed = new QCheckBox(i18n("Reverse direction"), this);
 	reversed->setChecked(slope->isReversed());
-	connect(reversed, SIGNAL(toggled(bool)), slope, SLOT(setReversed(bool)));
+	connect(reversed, &QCheckBox::toggled, slope, &Kolf::Slope::setReversed);
 	layout->addWidget(reversed, 1, 0);
 
 	QCheckBox* stuck = new QCheckBox(i18n("Unmovable"), this);
 	stuck->setChecked(slope->isStuckOnGround());
 	stuck->setWhatsThis(i18n("Whether or not this slope can be moved by other objects, like floaters."));
-	connect(stuck, SIGNAL(toggled(bool)), slope, SLOT(setStuckOnGround(bool)));
+	connect(stuck, &QCheckBox::toggled, slope, &Kolf::Slope::setStuckOnGround);
 	layout->addWidget(stuck, 1, 1);
 
 	layout->addWidget(new QLabel(i18n("Grade:"), this), 2, 0);
@@ -584,7 +584,7 @@ Kolf::SlopeConfig::SlopeConfig(Kolf::Slope* slope, QWidget* parent)
 	grade->setRange(0, 8);
 	grade->setSingleStep(1);
 	grade->setValue(slope->grade());
-	connect(grade, SIGNAL(valueChanged(double)), slope, SLOT(setGrade(double)));
+	connect(grade, QOverload<double>::of(&QDoubleSpinBox::valueChanged), slope, &Kolf::Slope::setGrade);
 	layout->addWidget(grade, 2, 1);
 
 	layout->setRowStretch(4, 10);
@@ -602,7 +602,7 @@ Kolf::SlopeOverlay::SlopeOverlay(Kolf::Slope* slope)
 		Kolf::OverlayHandle* handle = new Kolf::OverlayHandle(Kolf::OverlayHandle::CircleShape, this);
 		m_handles << handle;
 		addHandle(handle);
-		connect(handle, SIGNAL(moveRequest(QPointF)), this, SLOT(moveHandle(QPointF)));
+		connect(handle, &Kolf::OverlayHandle::moveRequest, this, &Kolf::SlopeOverlay::moveHandle);
 	}
 }
 
